Linux workstation

Fedora 43 native package

cubeb-devel

A cross platform audio library

Packages / Fedora 43 / Unspecified / cubeb-devel

[Source: cubeb]

Package: cubeb-devel (0.2-18.20230517.git48689ae.fc43)

[Project overview: cubeb]

External Resources:

Homepage: [github.com]

A cross platform audio library

Cubeb is a cross-platform library, written in C/C++, that was created and has been maintained by the Firefox Media Team. The role of the library is to communicate with audio devices and to provide audio input and/or output.

Other Packages Related to cubeb-devel:

  • dep: cmake-filesystem(aarch-64)

    Package not available

  • dep: ld-linux-aarch64.so.1()(64bit)

    Package not available

  • dep: ld-linux-aarch64.so.1(GLIBC_2.17)(64bit)

    Package not available

  • dep: libm.so.6()(64bit)

    Package not available

  • dep: libm.so.6(GLIBC_2.17)(64bit)

    Package not available

  • dep: libstdc++.so.6()(64bit)

    Package not available

  • dep: libstdc++.so.6(CXXABI_1.3)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.11)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.22)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.32)(64bit)

    Package not available

  • dep: libstdc++.so.6(GLIBCXX_3.4.9)(64bit)

    Package not available

  • dep: rtld(GNU_HASH)

    Package not available

  • dep: libc.so.6(GLIBC_2.38)(64bit)

    Package not available

Download cubeb-devel

ArchitecturePackage SizeInstalled SizeFiles
aarch64518 KiB2.6 MiB[list of files]
i686525 KiB2.0 MiB[list of files]
x86_64533 KiB2.6 MiB[list of files]

Шляхи файлів пакета (112)

Paths come from the repository package-file index for the observed builds. They describe archive/package associations, not every file that will exist on a running system after maintainer scripts, alternatives, generated state, diversions, or installation choices.

  • /usr/bin/cubeb-test
  • /usr/include/cubeb
  • /usr/include/cubeb/cubeb_export.h
  • /usr/include/cubeb/cubeb.h
  • /usr/lib64/cmake/cubeb
  • /usr/lib64/cmake/cubeb/cubebConfig.cmake
  • /usr/lib64/cmake/cubeb/cubebConfigVersion.cmake
  • /usr/lib64/cmake/cubeb/cubebTargets.cmake
  • /usr/lib64/cmake/cubeb/cubebTargets-relwithdebinfo.cmake
  • /usr/lib64/libcubeb.a
  • /usr/lib/.build-id
  • /usr/lib/.build-id/15
  • /usr/lib/.build-id/15/93af5dc80174bc0a02787774264e0b5080543f
  • /usr/lib/.build-id/3f
  • /usr/lib/.build-id/3f/22b3e6d6ead87dc13fb3fae6ce959ae8c68484
  • /usr/lib/.build-id/4e
  • /usr/lib/.build-id/4e/4f05f86eb3a47515ea4c0c3cad8037f865789c
  • /usr/lib/cmake/cubeb
  • /usr/lib/cmake/cubeb/cubebConfig.cmake
  • /usr/lib/cmake/cubeb/cubebConfigVersion.cmake
  • /usr/lib/cmake/cubeb/cubebTargets.cmake
  • /usr/lib/cmake/cubeb/cubebTargets-relwithdebinfo.cmake
  • /usr/lib/libcubeb.a
  • /usr/share/doc/cubeb
  • /usr/share/doc/cubeb/annotated_dup.js
  • /usr/share/doc/cubeb/annotated.html
  • /usr/share/doc/cubeb/classes.html
  • /usr/share/doc/cubeb/clipboard.js
  • /usr/share/doc/cubeb/cookie.js
  • /usr/share/doc/cubeb/cubeb_8h.html
  • /usr/share/doc/cubeb/cubeb_8h.js
  • /usr/share/doc/cubeb/cubeb_8h_source.html
  • /usr/share/doc/cubeb-devel
  • /usr/share/doc/cubeb-devel/README.md
  • /usr/share/doc/cubeb/dir_4a77ea686d101b1caa0240510cb36860.html
  • /usr/share/doc/cubeb/dir_4a77ea686d101b1caa0240510cb36860.js
  • /usr/share/doc/cubeb/dir_d44c64559bbebec7f509842c48db8b23.html
  • /usr/share/doc/cubeb/dir_d44c64559bbebec7f509842c48db8b23.js
  • /usr/share/doc/cubeb/doxygen_crawl.html
  • /usr/share/doc/cubeb/doxygen.css
  • /usr/share/doc/cubeb/doxygen.svg
  • /usr/share/doc/cubeb/dynsections.js
  • /usr/share/doc/cubeb/files_dup.js
  • /usr/share/doc/cubeb/files.html
  • /usr/share/doc/cubeb/functions.html
  • /usr/share/doc/cubeb/functions_vars.html
  • /usr/share/doc/cubeb/globals_defs.html
  • /usr/share/doc/cubeb/globals_enum.html
  • /usr/share/doc/cubeb/globals_eval.html
  • /usr/share/doc/cubeb/globals_func.html
  • /usr/share/doc/cubeb/globals.html
  • /usr/share/doc/cubeb/globals_type.html
  • /usr/share/doc/cubeb/index.html
  • /usr/share/doc/cubeb/jquery.js
  • /usr/share/doc/cubeb/menudata.js
  • /usr/share/doc/cubeb/menu.js
  • /usr/share/doc/cubeb/navtree.css
  • /usr/share/doc/cubeb/navtreedata.js
  • /usr/share/doc/cubeb/navtreeindex0.js
  • /usr/share/doc/cubeb/navtree.js
  • /usr/share/doc/cubeb/search
  • /usr/share/doc/cubeb/search/all_0.js
  • /usr/share/doc/cubeb/search/all_1.js
  • /usr/share/doc/cubeb/search/all_2.js
  • /usr/share/doc/cubeb/search/all_3.js
  • /usr/share/doc/cubeb/search/all_4.js
  • /usr/share/doc/cubeb/search/all_5.js
  • /usr/share/doc/cubeb/search/all_6.js
  • /usr/share/doc/cubeb/search/all_7.js
  • /usr/share/doc/cubeb/search/all_8.js
  • /usr/share/doc/cubeb/search/all_9.js
  • /usr/share/doc/cubeb/search/all_a.js
  • /usr/share/doc/cubeb/search/all_b.js
  • /usr/share/doc/cubeb/search/all_c.js
  • /usr/share/doc/cubeb/search/all_d.js
  • /usr/share/doc/cubeb/search/classes_0.js
  • /usr/share/doc/cubeb/search/defines_0.js
  • /usr/share/doc/cubeb/search/enums_0.js
  • /usr/share/doc/cubeb/search/enumvalues_0.js
  • /usr/share/doc/cubeb/search/files_0.js
  • /usr/share/doc/cubeb/search/functions_0.js
  • /usr/share/doc/cubeb/search/pages_0.js
  • /usr/share/doc/cubeb/search/pages_1.js
  • /usr/share/doc/cubeb/search/pages_2.js
  • /usr/share/doc/cubeb/search/search.css
  • /usr/share/doc/cubeb/search/searchdata.js
  • /usr/share/doc/cubeb/search/search.js
  • /usr/share/doc/cubeb/search/typedefs_0.js
  • /usr/share/doc/cubeb/search/variables_0.js
  • /usr/share/doc/cubeb/search/variables_1.js
  • /usr/share/doc/cubeb/search/variables_2.js
  • /usr/share/doc/cubeb/search/variables_3.js
  • /usr/share/doc/cubeb/search/variables_4.js
  • /usr/share/doc/cubeb/search/variables_5.js
  • /usr/share/doc/cubeb/search/variables_6.js
  • /usr/share/doc/cubeb/search/variables_7.js
  • /usr/share/doc/cubeb/search/variables_8.js
  • /usr/share/doc/cubeb/search/variables_9.js
  • /usr/share/doc/cubeb/search/variables_a.js
  • /usr/share/doc/cubeb/search/variables_b.js
  • /usr/share/doc/cubeb/search/variables_c.js
  • /usr/share/doc/cubeb/structcubeb__device__collection.html
  • /usr/share/doc/cubeb/structcubeb__device__collection.js
  • /usr/share/doc/cubeb/structcubeb__device.html
  • /usr/share/doc/cubeb/structcubeb__device__info.html
  • /usr/share/doc/cubeb/structcubeb__device__info.js
  • /usr/share/doc/cubeb/structcubeb__device.js
  • /usr/share/doc/cubeb/structcubeb__stream__params.html
  • /usr/share/doc/cubeb/structcubeb__stream__params.js
  • /usr/share/doc/cubeb/tabs.css
  • /usr/share/licenses/cubeb-devel
  • /usr/share/licenses/cubeb-devel/LICENSE

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

Використати цей пакет

OpenFactory може завантажити цю операційну систему у віртуальній машині браузера або почати збірку образу з рідною назвою пакета з цього запису.

Версії, набори та репозиторії

Кожен рядок: метадані індексу пакетів для однієї версії, архітектури, набору й репозиторію. Назви, URL і розміри зі джерела; посилання є змінним місцем отримання, не перерозповсюдженням OpenFactory.

VersionReleaseArchitectureRepositoryPackage sizeInstalled sizePublisher repository artifact
0.2-18.20230517.git48689ae.fc4343 / everythingaarch64Fedora 43 · Everything · aarch64518 KiB2.6 MiBPackages/c/cubeb-devel-0.2-18.20230517.git48689ae.fc43.aarch64.rpm
0.2-18.20230517.git48689ae.fc4343 / everythingi686Fedora 43 · Everything · x86_64525 KiB2.0 MiBPackages/c/cubeb-devel-0.2-18.20230517.git48689ae.fc43.i686.rpm
0.2-18.20230517.git48689ae.fc4343 / everythingx86_64Fedora 43 · Everything · x86_64533 KiB2.6 MiBPackages/c/cubeb-devel-0.2-18.20230517.git48689ae.fc43.x86_64.rpm

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

Контрольні суми й дати спостереження

For an APT source, signature verification authenticates the repository metadata chain and the Packages index containing this source-reported artifact digest. It does not certify package safety.

0.2-18.20230517.git48689ae.fc43 / aarch64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: 95b438251401ceab18f3b485dd64507ff1bed0a068f9fb1a5906a82bf6ec4cad

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' '95b438251401ceab18f3b485dd64507ff1bed0a068f9fb1a5906a82bf6ec4cad' 'cubeb-devel-0.2-18.20230517.git48689ae.fc43.aarch64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

0.2-18.20230517.git48689ae.fc43 / i686Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: f04cfc3ee814a4a2edf9e4357aa6279285b437aa5be0116ebb9397dc0f6ea193

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'f04cfc3ee814a4a2edf9e4357aa6279285b437aa5be0116ebb9397dc0f6ea193' 'cubeb-devel-0.2-18.20230517.git48689ae.fc43.i686.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

0.2-18.20230517.git48689ae.fc43 / x86_64Observed Sep 1, 2026 to Sep 1, 2026

Verification status: Metadata observed; artifact bytes were not independently fetched or hashed by this catalog import. The digest below is source-reported.

Source-reported sha256: c34ae763838bd88515a6fd6593441935b58f90868af99b236b02167e4422a480

After downloading that exact artifact, compare its bytes with the source-reported expected digest:

printf '%s %s\n' 'c34ae763838bd88515a6fd6593441935b58f90868af99b236b02167e4422a480' 'cubeb-devel-0.2-18.20230517.git48689ae.fc43.x86_64.rpm' | sha256sum --check --strict -

A match establishes equality with the repository metadata value. It does not establish safety or catalog-side artifact retrieval.

Field source: Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

Повнота запису каталогу

The completeness score measures metadata coverage, not software quality, security, compatibility, or suitability.

Summary and description
25/25
Artifact path and source digest
25/25
Dependency metadata
15/15
Package-file index
15/15
Homepage
5/5
License text
5/5
Source package or maintainer
10/10

Recorded total: 100/100

Field source: Fedora 43 Everything aarch64 revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2, Fedora 43 Everything x86_64 revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2. The cross-OS mapping is catalog-derived from the source-reported homepage; it does not establish authorship or publisher identity

Джерела та походження

Field-source links above resolve here. Each source entry names the metadata publisher, trust tier, exact snapshot revision, signature result, and observation time; catalog-derived mappings are labeled separately.

  • Authoritative source; repository metadata signature verified, revision 43-everything-aarch64:6431612747d987257399969298151d19cfe87ed26322be6987e7b00cd0ae66a2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    6c2a7b7225a6bd12acd5c95dcd0350a0a5929e195692ff68eb31db0ee6b9897b
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

  • Authoritative source; repository metadata signature verified, revision 43-everything-x86_64:eb1d8634a798b5cfcef64b0114711f431f2cd186b55cce902f1883a32c6ff4f2

    Signature verification covers the configured repository metadata chain. It does not certify that the package is safe or suitable.

    Repository-signature verification record
    Signed-object SHA-256
    42c0002750de6066124693fff143f4854c1e29474d893f7e6a7616012d41338f
    Signer fingerprint
    Not recorded
    Keyring revision
    RPM-GPG-KEY-fedora-43-primary
    SHA-256 2b1449a082d3264dda8e18369f04e9ac4163bf3f8cb530b0783dc2ab064a08ec
    Tool and policy
    1
    openfactory-software-catalog-signature-v1
    Verification time
    Sep 1, 2026
    Signed Release → package-index hash linkage

    Path: Not recorded
    Expected SHA-256: Not recorded
    Observed SHA-256: Not recorded
    Result: match verified

cubeb-devel Package for Fedora 43 | OpenFactory